import { dirname, isAbsolute, relative } from 'path';
import { DEFAULT_ARBITRARY_EXTENSIONS } from '../config.js';
import { exists } from '../util.js';
import { generateDtsContentWithSourceMap, getDtsFilePath } from './dts.js';
import { writeFileIfChanged } from './file-system.js';
import { generateSourceMappingURLComment, getSourceMapFilePath } from './source-map.js';
export function getRelativePath(fromFilePath, toFilePath) {
    const resolved = relative(dirname(fromFilePath), toFilePath);
    if (resolved.startsWith('..')) {
        return resolved;
    }
    else {
        return './' + resolved;
    }
}
export function isSubDirectoryFile(fromDirectory, toFilePath) {
    return isAbsolute(toFilePath) && toFilePath.startsWith(fromDirectory);
}
export async function emitGeneratedFiles({ filePath, tokens, emitDeclarationMap, dtsFormatOptions, isExternalFile, }) {
    const arbitraryExtensions = dtsFormatOptions?.arbitraryExtensions ?? DEFAULT_ARBITRARY_EXTENSIONS;
    const dtsFilePath = getDtsFilePath(filePath, arbitraryExtensions);
    const sourceMapFilePath = getSourceMapFilePath(filePath, arbitraryExtensions);
    const { dtsContent, sourceMap } = generateDtsContentWithSourceMap(filePath, dtsFilePath, sourceMapFilePath, tokens, dtsFormatOptions, isExternalFile);
    if (emitDeclarationMap) {
        const sourceMappingURLComment = generateSourceMappingURLComment(dtsFilePath, sourceMapFilePath);
        await writeFileIfChanged(dtsFilePath, dtsContent + sourceMappingURLComment);
        // NOTE: tsserver does not support inline declaration maps. Therefore, sourcemap files must be output.
        // blocked by: https://github.com/microsoft/TypeScript/issues/38966
        await writeFileIfChanged(sourceMapFilePath, sourceMap.toString());
    }
    else {
        await writeFileIfChanged(dtsFilePath, dtsContent);
    }
}
/**
 * Returns true if .d.ts (and .d.ts.map) files are generated for the given file.
 */
export async function isGeneratedFilesExist(filePath, emitDeclarationMap, arbitraryExtensions) {
    const dtsFilePath = getDtsFilePath(filePath, arbitraryExtensions);
    const sourceMapFilePath = getSourceMapFilePath(filePath, arbitraryExtensions);
    if (emitDeclarationMap && !(await exists(sourceMapFilePath))) {
        return false;
    }
    if (!(await exists(dtsFilePath))) {
        return false;
    }
    return true;
}
//# sourceMappingURL=index.js.map