import { type Rule, type AtRule, type Root, type Declaration } from 'postcss';
import { type ClassName } from 'postcss-selector-parser';
/** The pair of line number and column number. */
export type Position = {
    /** The line number in the source file. It is 1-based (compatible with postcss). */
    line: number;
    /** The column number in the source file. It is 1-based (compatible with postcss). */
    column: number;
};
/** The original location of class selector. If the original location is not found, all fields are `undefined`. */
export type Location = {
    filePath: string;
    /** The inclusive starting position of the node's source (compatible with postcss). */
    start: Position;
    /** The inclusive ending position of the node's source (compatible with postcss). */
    end: Position;
} | {
    filePath: undefined;
    start: undefined;
    end: undefined;
};
/**
 * Traverses a local token from the AST and returns its name.
 * @param ast The AST to traverse.
 * @returns The name of the local token.
 */
export declare function generateLocalTokenNames(ast: Root): Promise<string[]>;
/**
 * Get the token's location on the source file.
 * @param rule The rule node that contains the token.
 * @param classSelector The class selector node that contains the token.
 * @returns The token's location on the source file.
 */
export declare function getOriginalLocation(rule: Rule, classSelector: ClassName): Location;
type CollectNodesResult = {
    atImports: AtRule[];
    classSelectors: {
        rule: Rule;
        classSelector: ClassName;
    }[];
    composesDeclarations: Declaration[];
};
/**
 * Collect nodes from the AST.
 * @param ast The AST.
 */
export declare function collectNodes(ast: Root): CollectNodesResult;
/**
 * Parse the `@import` rule.
 * @param atImport The `@import` rule to parse.
 * @returns The imported sheet path.
 */
export declare function parseAtImport(atImport: AtRule): string | undefined;
/**
 * Parse `composes` declaration with `from <url>`.
 * If the declaration is not found or do not have `from <url>`, return `undefined`.
 * @param composesDeclaration The `composes` declaration to parse.
 * @returns The information of the declaration.
 */
export declare function parseComposesDeclarationWithFromUrl(composesDeclaration: Declaration): {
    from: string;
    tokenNames: string[];
} | undefined;
export {};
