import type { WebpackResolverOptions } from './webpack-resolver.js';
export type ResolverOptions = {
    request: string;
};
/**
 * The function to resolve the path of the imported file.
 * @returns The resolved path of the imported file. `false` means to skip resolving.
 * */
export type Resolver = (specifier: string, options: ResolverOptions) => string | false | Promise<string | false>;
export type DefaultResolverOptions = WebpackResolverOptions;
/**
 * The Default resolver.
 *
 * This resolver implements a resolve algorithm that is as compatible as possible with the major toolchains,
 * including Node.js, webpack (css-loader, sass-loader, less-loader) and vite. It is difficult to completely
 * mimic the behavior of these toolchains, so the behavior may differ in some cases.
 *
 * @param specifier The specifier to resolve (i.e. './foo.css', '~bootstrap', etc.)
 * @param options The options to resolve
 * @returns The resolved path (absolute). `false` means to skip resolving.
 */
export declare const createDefaultResolver: (defaultResolverOptions?: DefaultResolverOptions | undefined) => Resolver;
