import { constants, mkdirSync, realpathSync, rmSync, writeFileSync } from 'fs';
import { access } from 'fs/promises';
import { tmpdir } from 'os';
import { dirname, join, resolve } from 'path';
import postcss from 'postcss';
import { collectNodes } from '../locator/index.js';
import { sleepSync } from '../util.js';
export const FIXTURE_DIR_PATH = resolve(realpathSync(tmpdir()), 'happy-css-modules/fixtures', process.env['JEST_WORKER_ID']);
export function createRoot(code, from) {
    return postcss.parse(code, { from: from || '/test/test.css' });
}
export function createAtImports(root) {
    return collectNodes(root).atImports;
}
export function createClassSelectors(root) {
    return collectNodes(root).classSelectors;
}
export function createComposesDeclarations(root) {
    return collectNodes(root).composesDeclarations;
}
export function fakeToken(args) {
    return {
        name: args.name,
        originalLocations: args.originalLocations.map((location) => {
            if (location.filePath === undefined || location.start === undefined) {
                return { filePath: undefined, start: undefined, end: undefined };
            }
            else {
                return {
                    filePath: location.filePath ?? getFixturePath('/test/1.css'),
                    start: location.start,
                    end: {
                        line: location.start.line,
                        column: location.start.column + args.name.length - 1,
                    },
                };
            }
        }),
    };
}
export async function waitForAsyncTask(ms) {
    await new Promise((resolve) => setTimeout(resolve, ms ?? 0));
}
export async function exists(path) {
    try {
        await access(path, constants.F_OK);
        return true;
    }
    catch (e) {
        return false;
    }
}
function isFile(item) {
    return typeof item === 'string';
}
export function createFixtures(items) {
    function createFixturesImpl(items, baseDir) {
        for (const [name, item] of Object.entries(items)) {
            const path = join(baseDir, name);
            if (isFile(item)) {
                mkdirSync(dirname(path), { recursive: true });
                if (typeof item === 'string') {
                    writeFileSync(path, item);
                }
            }
            else {
                mkdirSync(path, { recursive: true });
                createFixturesImpl(item, path);
            }
        }
    }
    removeFixtures();
    sleepSync(2); // Wait 2 ms for mtime to change from the previous fixture.
    createFixturesImpl(items, FIXTURE_DIR_PATH);
}
export function removeFixtures() {
    rmSync(FIXTURE_DIR_PATH, { recursive: true, force: true });
}
export function getFixturePath(path) {
    return join(FIXTURE_DIR_PATH, path);
}
//# sourceMappingURL=util.js.map