import { createLessTransformer } from './less-transformer.js';
import { createPostcssTransformer } from './postcss-transformer.js';
import { createScssTransformer } from './scss-transformer.js';
// eslint-disable-next-line @typescript-eslint/no-unused-vars -- TODO: pass `e` to Error's cause option
export const handleImportError = (packageName) => (e) => {
    throw new Error(`${packageName} import failed. Did you forget to \`npm install -D ${packageName}\`?`);
};
export const createDefaultTransformer = (defaultTransformerOptions) => {
    const scssTransformer = createScssTransformer();
    const lessTransformer = createLessTransformer();
    const postcssTransformer = createPostcssTransformer(defaultTransformerOptions);
    return async (source, options) => {
        if (options.from.endsWith('.scss')) {
            return scssTransformer(source, options);
        }
        else if (options.from.endsWith('.less')) {
            return lessTransformer(source, options);
        }
        else {
            // TODO: Support multi-stage transformations by sass and less.
            return postcssTransformer(source, options);
        }
    };
};
//# sourceMappingURL=index.js.map